==> walkers-fabric-1.18.2-4.5-sources.jar: tocraft/walkers/traits/impl/StandOnFluidTrait.java <==
package tocraft.walkers.traits.impl;

import com.mojang.serialization.Codec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_1058;
import net.minecraft.class_1087;
import net.minecraft.class_1309;
import net.minecraft.class_1802;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_3611;
import net.minecraft.class_6862;
import org.jetbrains.annotations.Nullable;
import tocraft.walkers.Walkers;
import tocraft.walkers.traits.ShapeTrait;

public class StandOnFluidTrait<E extends class_1309> extends ShapeTrait<E> {
    public static final class_2960 ID = Walkers.id("stand_on_fluid");
    public static final Codec<StandOnFluidTrait<?>> CODEC = RecordCodecBuilder.create((instance) -> instance.group(
            class_2960.field_25139.fieldOf("fluid").forGetter(o -> o.fluidTagKey.comp_327())
    ).apply(instance, instance.stable(fluid -> new StandOnFluidTrait<>(class_6862.method_40092(class_2378.field_25103, fluid)))));

    public final class_6862<class_3611> fluidTagKey;


    public StandOnFluidTrait(class_6862<class_3611> fluidTagKey) {
        this.fluidTagKey = fluidTagKey;
    }

    @Override
    public class_2960 getId() {
        return ID;
    }

    @Override
    public Codec<? extends ShapeTrait<?>> codec() {
        return CODEC;
    }

    @Override
    @Environment(EnvType.CLIENT)
    public @Nullable class_1058 getIcon() {
        class_1087 itemModel = class_310.method_1551().method_1480().method_4012().method_3304(class_1802.field_8533);
        if (itemModel != null) {
            return itemModel.method_4711();
        } else {
            return super.getIcon();
        }
    }
}

==> walkers-fabric-1.19.4-5.3-sources.jar: tocraft/walkers/traits/impl/StandOnFluidTrait.java <==
package tocraft.walkers.traits.impl;

import com.mojang.serialization.MapCodec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_1058;
import net.minecraft.class_1087;
import net.minecraft.class_1309;
import net.minecraft.class_1802;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_3611;
import net.minecraft.class_5321;
import net.minecraft.class_6862;
import org.jetbrains.annotations.Nullable;
import tocraft.craftedcore.patched.CRegistries;
import tocraft.craftedcore.patched.Identifier;
import tocraft.walkers.Walkers;
import tocraft.walkers.traits.ShapeTrait;

public class StandOnFluidTrait<E extends class_1309> extends ShapeTrait<E> {
    public static final class_2960 ID = Walkers.id("stand_on_fluid");
    public static final MapCodec<StandOnFluidTrait<?>> CODEC = RecordCodecBuilder.mapCodec((instance) -> instance.group(
            class_2960.field_25139.fieldOf("fluid").forGetter(o -> o.fluidTagKey.comp_327())
    ).apply(instance, instance.stable(fluid -> new StandOnFluidTrait<>(class_6862.method_40092((class_5321<? extends class_2378<class_3611>>) CRegistries.getRegistry(Identifier.parse("fluid")).method_30517(), fluid)))));

    public final class_6862<class_3611> fluidTagKey;


    public StandOnFluidTrait(class_6862<class_3611> fluidTagKey) {
        this.fluidTagKey = fluidTagKey;
    }

    @Override
    public class_2960 getId() {
        return ID;
    }

    @Override
    public MapCodec<? extends ShapeTrait<?>> codec() {
        return CODEC;
    }

    @Override
    @Environment(EnvType.CLIENT)
    public @Nullable class_1058 getIcon() {
        class_1087 itemModel = class_310.method_1551().method_1480().method_4012().method_3304(class_1802.field_8533);
        if (itemModel != null) {
            return itemModel.method_4711();
        } else {
            return super.getIcon();
        }
    }
}
